@@ -35,10 +35,25 @@ Last-Updated: @{[ scalar localtime ]}
 
 EOF
     for my $p ($self->packages) {
-        print $fh sprintf "%s %s  %s\n", pad($p->name, 32), pad($p->version || 'undef', 10, 1), $p->pathname;
+        print $fh $self->_format_line($p->name, $p->version || 'undef', $p->pathname);
     }
 }
 
+sub _format_line {
+    my($self, @row) = @_;
+
+    # from PAUSE::mldistwatch::rewrite02
+    my $one = 30;
+    my $two = 8;
+
+    if (length $row[0] > $one) {
+        $one += 8 - length $row[1];
+        $two = length $row[1];
+    }
+
+    sprintf "%-${one}s %${two}s  %s\n", @row;
+}
+
 sub pad {
     my($str, $len, $left) = @_;
 
